function CNDikeGridSensitivity(Param,scxy,tolerance,noise,ggridxy)
% A function that shows how sensitive the grid is to the different
% parameters for a dike intrusion
% inputs: Param = Data structure with model parameters.
%                 Elements should be:
%                 Param.t = dike thicknesses
%                 Param.h = dike heights
%                 Param.l = vertical extents of dike
%                 Param.rhos = density contrasts for dike
%                  example parameters
%                   Param.t=(.5:.5:5); 
%                   Param.h=(500:500:6000);
%                   Param.l=(500:500:5000);
%                   Param.rhos=(100:100:1000);
%         scxy=UTM coordinates of the end points of the dike,
%                      N first, S second
%         tolerance=number of stations necessary so that the source is
%                   considered "detected"
%         noise=noise of the meter, .1 mGal for Bouguer, .015 for dynamic
%         ggrid=UTM coordinates of the gravity grid
%
%
%-----------------------------------------------------------------------------
%Code written by Patricia MacQueen (pmacquee@gmail.com), December 6, 2013.
%If you use this code, please credit me appropriately.
%-----------------------------------------------------------------------------

%%%variables%%%
t=Param.t; %dike thickness
h=Param.h;%depth to top of dike
l=Param.l;%vertical extent of dike
rhos=Param.rhos; %density contrasts
G=6.67e-11;%gravitational constant
%%%%%%%%%%%%%%%

%Preallocate N
NCN=zeros(length(t)*length(h)*length(l)*length(rhos),4);
counterind=0;%counter variable to keep track of rows.
goodcountind=0;%holds row locations of detectable parameter combinations
badcountind=0;%holds row locations of undetectable parameter combinations
fullind=zeros(length(t)*length(h)*length(l)*length(rhos),1);%Matrix that will hold detectable combinations of parameters
zeroind=zeros(length(t)*length(h)*length(l)*length(rhos),1);%Matrix that will hold undetectable combinations of parameters



%Do stuff to turn an infinte dike into one that's at least calculated finitely 
%Basically, this make it so the code will only calculate gravity signals
%for stations that fall directly on either side of the dike, and not past
%the endpoints.  Because past the endpoints is not easy math, you see.

%find line equation for end points of dike
pdike=polyfit(scxy(:,1),scxy(:,2),1);
%define lines that define the exclusion zone
mexline=-1/pdike(1);%slope of exclusion line
bx1=scxy(1,2)-(mexline*scxy(1,1));%y intercept to define north exclusion line
bx2=scxy(2,2)-(mexline*scxy(2,1));%y intercept to define south exclusion line
%north exclusion line: y=mexline*x+bx1
%south exclusion line: y=mexline*x+bx2

%take only stations within exclusion zone for calculations
%actual stations
clear i j
counterindggrid=0;
ggridinind=zeros(length(ggridxy),1);
for i=1:length(ggridxy)
    counterindggrid=counterindggrid+1;
    if (ggridxy(i,2)<(mexline*ggridxy(i,1)+bx1))&&(ggridxy(i,2)>(mexline*ggridxy(i,1)+bx2))
        ggridinind(i)=counterindggrid;
    end
end
ggridinind=ggridinind(ggridinind~=0);%take out zeros from indexing vector.
ggridxyin=ggridxy(ggridinind,:);%vector containing coordinates of stations within exclusion zone


%calculate distance from stations in calculation zone to dike line
%actual stations
clear i j
rgrid=zeros(length(ggridxyin),1);
for i=1:length(ggridxyin)
    rgrid(i)=abs((scxy(2,1)-scxy(1,1))*(scxy(1,2)-ggridxyin(i,2))-(scxy(1,1)-ggridxyin(i,1))*(scxy(2,2)-scxy(1,2)))/sqrt((scxy(2,1)-scxy(1,1))^2+(scxy(2,2)-scxy(1,2))^2);
end

%Find which stations are above noise level for all depth/volume/rho
%combinations
for i=1:length(t)
    for j=1:length(h)
        for k=1:length(l)
            for squid=1:length(rhos)
                delgr=2*G*rhos(squid)*t(i).*log(((h(j)+l(k))^2+rgrid.^2)./(rgrid.^2+h(j)^2))*1e5; %calculate gravity at each station in mGal
                goodstat=delgr(delgr>noise);%creat a vector containing only gravity values above noise
                counterind=counterind+1;
                NCN(counterind,1:4)=[t(i) h(j) l(k) rhos(squid)];
                  if length(goodstat)>=tolerance %if there are more than (tolerance) stations above noise then keep those values, if not, put zeros
                      goodcountind=goodcountind+1;  
                      fullind(goodcountind)=counterind; %INDEXING IS YOUR FRIEND
                  elseif length(goodstat)<tolerance
                        badcountind=badcountind+1;
                        zeroind(badcountind)=counterind;
                  end
             end
         end
     end
end
%pare down fullind and zeroind to get rid of uneccesary zeros
fullind=fullind(fullind~=0);%indices of good combinations
zeroind=zeroind(zeroind~=0);%indices of bad combinations

%plot results
figure('name','Sensitivity of Grid')
%thickness vs depth to dike
subplot(2,3,1)
hold on
plot(NCN(fullind,2),NCN(fullind,1),'b*')%plot detectable combinations
plot(NCN(zeroind,2),NCN(zeroind,1),'or')%plot non-detectable combinations
title('Thickness vs Depth to Dike')
xlabel('Depth to Dike (m)')
ylabel('Thickness (m)')
legend('Detectable','Not Detectable','Location','SouthOutside');
%thickness vs vertical extent of dike
subplot(2,3,2)
hold on
plot(NCN(fullind,3),NCN(fullind,1),'b*')%plot detectable combinations
plot(NCN(zeroind,3),NCN(zeroind,1),'or')%plot non-detectable combinations
title({['Tolerance= ' num2str(tolerance) ',noise= ' num2str(noise) ', source= (' num2str(scxy(1,1)) ',' num2str(scxy(1,2)) ') to (' num2str(scxy(2,1)) ',' num2str(scxy(2,2)) ')'];'Thickness vs Vertical Extent of Dike'})
xlabel('Vertical Extent of Dike (m)')
ylabel('Thickness (m)')
legend('Detectable','Not Detectable','Location','SouthOutside');
%thickness vs density contrast
subplot(2,3,3)
hold on
plot(NCN(fullind,4),NCN(fullind,1),'b*')%plot detectable combinations
plot(NCN(zeroind,4),NCN(zeroind,1),'or')%plot non-detectable combinations
title('Thickness vs Density Contrast')
xlabel('Density Contrast (kg/m\^3)')
ylabel('Thickness (m)')
legend('Detectable','Not Detectable','Location','SouthOutside');
%Depth to Dike vs Vertical Extent of Dike
subplot(2,3,4)
hold on
plot(NCN(fullind,3),NCN(fullind,2),'b*')%plot detectable combinations
plot(NCN(zeroind,3),NCN(zeroind,2),'or')%plot non-detectable combinations
title('Depth to Dike vs Vertical Extent of Dike')
xlabel('Vertical Extent of Dike (m)')
ylabel('Depth to Dike (m)')
legend('Detectable','Not Detectable','Location','SouthOutside');
%Depth to Dike vs Density Contrast
subplot(2,3,5)
hold on
plot(NCN(fullind,4),NCN(fullind,2),'b*')%plot detectable combinations
plot(NCN(zeroind,4),NCN(zeroind,2),'or')%plot non-detectable combinations
title('Depth to Dike vs Density Contrast')
xlabel('Density Contrast (kg/m\^3)')
ylabel('Depth to Dike (m)')
legend('Detectable','Not Detectable','Location','SouthOutside');
%Vertical Extent of Dike vs Density Contrast
subplot(2,3,6)
hold on
plot(NCN(fullind,4),NCN(fullind,3),'b*')%plot detectable combinations
plot(NCN(zeroind,4),NCN(zeroind,3),'or')%plot non-detectable combinations
title('Vertical Extent of Dike vs Density Contrast')
xlabel('Density Contrast (kg/m\^3)')
ylabel('Vertical Extent of Dike (m)')
legend('Detectable','Not Detectable','Location','SouthOutside');
