function [maxgrav,delgr,r]=basicgrav(delV,rhocon,d,rmax,dynswitch)
%A basic program for testing simple mogi source gravity changes or gravity
%from a spherical source
%The Mogi source assumes a Poisson's ratio of 2.5
%Inputs: delV=volume change in m cubed
%        rhocon=density contrast between source and crust (kg/m^3)
%        d=depth center of source
%        r=maximum distance from source at which to calculate gravity.  Make this
%        bigger for larger/deeper sources to be able to see the whole signal
%        dynswitch= 1 for dynamic gravity, 2 for static gravity (instead of
%        change in volume is simply the volume of a spherical source)
%Outputs: maxgrav=maximum gravity change (ie, gravity change directly above
%         soure in mGal
%         delgr=vector containing gravity change values (for certain
%         distances from source) in mGal
%         r=vector containing distances from source in m
%
%
%-----------------------------------------------------------------------------
%Code written by Patricia MacQueen (pmacquee@gmail.com), December 6, 2013.
%If you use this code, please credit me appropriately.
%-----------------------------------------------------------------------------

%Constants
G=6.67e-11;%gravitational constant
rhoc=2600;%density of basaltic crust
nu=.25;%Poisson's ratio

r=linspace(1,10000,rmax);%vector containing distances from source at which to calculate gravity change.

switch dynswitch
    case 1
        % calculate gravity change (After Dzurisin and Mori 2007)
        %gravity change due to addition of mass
        gmass=(G*(rhocon)*delV*(d./(r.^2+d^2).^(3/2)))*1e5;%in mGal
        
        %gravity change due to uplift from inflating point source
        ginflate=(2*G*rhoc*(1-nu)*delV*(d./(r.^2+d^2).^(3/2)))*1e5;
        
        %gravity change due to elastic expansion of crust changing density
        gelastic=(-G*rhoc*(1-2*nu)*delV*(d./(r.^2+d^2).^(3/2)))*1e5;
        
        %calculate total gravity change in m/s^2
        delgr=gmass+ginflate+gelastic;
        
        maxgrav=max(delgr);
        
        % graph of gravity change (from different contributing factors) vs. distance to source
        figure('name','Gravity Change vs Distance from Source')
        hold on
        plot(r,delgr,'k-','LineWidth',2);
        plot(r,gmass,'r-');
        plot(r,ginflate,'b-');
        plot(r,gelastic,'g-');
        legend('total gravity change','gravity change from mass addition','gravity change from uplift','gravity change from elastic expansion of crust','Location','SouthOutside');
        title({'Gravity Change vs Distance from Source';['Volume Change=' num2str(delV) ', Density Contrast=' num2str(rhocon)];[', Depth to source=' num2str(d)]});
        xlabel('Distance from source (m)');
        ylabel('Gravity Change (mGal)')
        
    case 2
        %calculate gravity along points in r
        delgr=((G*rhocon*d*delV)./(r.^2+d^2).^(1.5)).*1e5;%calculate gravity signal due to source in mGal
        maxgrav=max(delgr);
        figure('name','Gravity vs Distance from Source')
        hold on
        %gravity of gravity vs distance to source
        plot(r,delgr,'k-','LineWidth',2);
        legend('gravity','Location','SouthOutside');
        title({'Gravity Change vs Distance from Source';['Volume Change=' num2str(delV) ', Density Contrast=' num2str(rhocon)];[', Depth to source=' num2str(d)]});
        xlabel('Distance from source (m)');
        ylabel('Gravity Change (mGal)')
end
        