function [resolution]=rescalc(loc)
%Calculates spatial changes in Nyquist limit resolution for an irregular gravity
%measurement grid.  Produces a matrix with UTM coordinates for the midpoints 
%between closest stations and corresponding Nyquist limit that can also be 
% gridded and displayed in Surfer.
%
%inputs:
%loc = Locations of measurement sites in UTM coordinates, column vector
%   with easting first column, northing second column
%
%outputs:
%resolution = midpoints between closest measurement points and corresponding
%   resolution
%
%figures:
%'Calculated Resolution' = Map of resolution, red is high resolution
%   (smaller targets detectable), blue is low resolution
%
%
%-----------------------------------------------------------------------------
%Code written by Patricia MacQueen (pmacquee@gmail.com), December 6, 2013.
%If you use this code, please credit me appropriately.
%-----------------------------------------------------------------------------

%calculates the distances between all the points in the grid
distances=pdist(loc,'euclidean');
%reshapes into a more usefully shaped matrix 
distances=squareform(distances);
%turns all the 0 values into nan so they aren't included when looking for a
%minimum
distances(~distances)=nan;
%finds the minimum distance away from each station to the next nearest
%station and the corresponding closest station
[mindist,minind]=min(distances);
%multiplies these minimum values by 2 to get the Nyquist limit
resdist=mindist.*2;

%finds midpoints for plotting 
mdpts=zeros(length(loc),2);
for i=1:length(loc)
    mdpts(i,1)=(loc(i,1)+loc(minind(i),1))/2;
    mdpts(i,2)=(loc(i,2)+loc(minind(i),2))/2;
end

%builds output "resolution" matrix with UTM coordinates for midpoints and
%corresponding Nyquist resolution
resolution=mdpts;
resolution(:,3)=resdist';

%Plots the Nyquist resolution

%interpolates the Nyquist resolution
eastreg=linspace(min(loc(:,1)),max(loc(:,1)),300);
northreg=linspace(min(loc(:,2)),max(loc(:,2)),300);
[X,Y]=meshgrid(eastreg,northreg);
RESFUN=TriScatteredInterp(resolution(:,1),resolution(:,2),resolution(:,3));
RES=RESFUN(X,Y);
%plots the interpolated Nyquist resolution
figure('name','Calculated Resolution');mesh(X,Y,RES);view(2);
colormap(flipud(colormap))%flips the colormap so red is high and blue is low resolution
maxheight(1:length(loc))=max(resdist);%creates a height variable to plot visible station locations
hold on;plot3(resolution(:,1),resolution(:,2),maxheight,'*')%plot station locations
colorbar()%plots a colorbar
